#! /bin/bash
#
#  fotoxx v.6.7
#  check if dependencies are installed before build
#

dlist="g++  exiftool  ufraw  xdg-open  /usr/include/gtk-2.0/gtk/gtk.h  
             /usr/include/FreeImage.h  /usr/lib*/libfreeimage.so"
error=0

for dname in $dlist
do
   if [ ${dname:0:1} = "/" ] 
      then find $dname >/dev/null 2>&1
      else which $dname >/dev/null
   fi
   if [ $? -ne 0 ]; then error=1; fi
done
if [ $error -eq 0 ]; then exit 0; fi

echo ""
echo "Fotoxx has the following dependencies. The first three are"
echo "required for installation and the remaining for operation."
echo "Exact package names depend on your Linux distribution."
echo ""
echo "g++                  the Gnu C++ compiler and linker"
echo "libgtk2.0-dev        GTK graphics library (GUI base)"
echo "libfreeimage-dev     FreeImage graphics library"
echo "exiftool             read and write EXIF data"
echo "ufraw                read digital camera RAW files"
echo "xdg-utils            LSB standard Linux utilities"
echo ""

for dname in $dlist
do
   if [ ${dname:0:1} = "/" ] 
      then find $dname >/dev/null 2>&1
      else which $dname >/dev/null
   fi
   if [ $? -ne 0 ]
      then echo " missing:  $dname"
      else echo "   found:  $dname"
   fi
done

echo ""
echo "Please install missing dependencies."
echo ""
exit 1


